@@ -9,11 +9,11 @@ class DeliveryService(BaseService):
     def __init__(self, client):
         super().__init__(client, service_name='delivery')
 
-    def get_signed_urls(self, srns: [str]):
+    def get_signed_urls(self, srns: list):
+        """Given a list of SRNs representing files, return the signed URLs for those files."""
         url = f'{self._service_url}/GetFileSignedUrl'
         query = { 'srns': srns }
         response = requests.post(url=url, headers=self._headers(), json=query)
-        if not response.ok:
-            raise Exception(f'HTTP {response.status_code}', response.reason, response.text)
+        response.raise_for_status()
 
         return response.json()
